@@ -4,7 +4,7 @@ from mprop import mproperty
 from subprocess import Popen, PIPE
 import sys
 
-__version__ = "0.109.1"
+__version__ = "0.121.2"
 
 __github_repo = "jupyter-naas/drivers"
 
@@ -440,3 +440,10 @@ def linkedin_salesnavigator():
     from naas_drivers.tools.linkedin_salesnavigator import LinkedIn
 
     return LinkedIn()
+
+
+@load_driver
+def naas_chat_plugin():
+    from naas_drivers.tools.naas_chat_plugin import NaasChatPlugin
+
+    return NaasChatPlugin()
