@@ -19,7 +19,12 @@ class HSCRUD:
         self.model_name = self.base_url.split("/")[-1]
 
         # Manage message
-        message_dict = {"contacts": "Contact", "company": "Company", "deals": "Deal"}
+        message_dict = {
+            "contacts": "Contact",
+            "company": "Company",
+            "companies": "Company",
+            "deals": "Deal",
+        }
         self.msg = message_dict[self.model_name]
 
     def __values_format(self, data):
@@ -89,13 +94,15 @@ class HSCRUD:
             self.params = params
         return df
 
-    def get(self, uid, hs_properties=None, idproperty=None):
+    def get(self, uid, hs_properties=None, idproperty=None, hs_associations=None):
         params = self.params
         # Get contact with property email
         if idproperty:
             params["idProperty"] = idproperty
         if hs_properties:
             params["properties"] = hs_properties
+        if hs_associations:
+            params["associations"] = hs_associations
         res = requests.get(
             url=f"{self.base_url}/{uid}",
             headers=self.req_headers,
@@ -444,6 +451,9 @@ class HubSpot(InDriver, OutDriver):
             f"{self.obj_url}/contacts", self.req_headers, self.params
         )
         self.company = HSCRUD(f"{self.obj_url}/company", self.req_headers, self.params)
+        self.companies = HSCRUD(
+            f"{self.obj_url}/companies", self.req_headers, self.params
+        )
         self.deals = Deal(f"{self.obj_url}/deals", self.req_headers, self.params)
         self.pipelines = Pipeline(
             f"{self.pip_url}/deals", self.req_headers, self.params
