@@ -82,17 +82,18 @@ class LinkedIn:
         if "-activity-" in url:
             return url.split("-activity-")[-1].split("-")[0]
         if ":activity:" in url:
-            return url.split(":activity:")[-1]
+            return url.split(":activity:")[-1].split("/")[0]
+
+    @staticmethod
+    def get_profile_id(url):
+        return url.rsplit("/in/")[-1].rsplit("/")[0]
 
     def print_deprecated(self, new_funct):
         if self.deprected:
             print(f"This function is deprecated, please use {new_funct}")
 
-    def get_profile_id(self, url):
-        return url.rsplit("/in/")[-1].rsplit("/")[0]
-
     def get_profile_urn(self, url):
-        lk_id = self.get_profile_id(url)
+        lk_id = LinkedIn.get_profile_id(url)
         res = requests.get(
             f"https://www.linkedin.com/voyager/api/identity/profiles/{lk_id}",
             cookies=self.cookies,
@@ -195,7 +196,7 @@ class Profile(LinkedIn):
             print("❌ No profile URL. Please enter a profile URL from LinkedIn")
             return res_json
         result = {}
-        lk_public_id = self.get_profile_id(profile_url)
+        lk_public_id = LinkedIn.get_profile_id(profile_url)
         req_url = (
             f"https://www.linkedin.com/voyager/api/identity/profiles/{lk_public_id}"
         )
@@ -282,7 +283,7 @@ class Profile(LinkedIn):
             print("❌ No profile URL. Please enter a profile URL from LinkedIn")
             return res_json
         result = {}
-        lk_id = self.get_profile_id(profile_url)
+        lk_id = LinkedIn.get_profile_id(profile_url)
         req_url = f"https://www.linkedin.com/voyager/api/identity/profiles/{lk_id}/networkinfo"
         res = requests.get(req_url, cookies=self.cookies, headers=self.headers)
         # Raise error
@@ -330,7 +331,7 @@ class Profile(LinkedIn):
             print("❌ No profile URL. Please enter a profile URL from LinkedIn")
             return res_json
         result = {}
-        lk_id = self.get_profile_id(profile_url)
+        lk_id = LinkedIn.get_profile_id(profile_url)
         req_url = f"https://www.linkedin.com/voyager/api/identity/profiles/{lk_id}/profileContactInfo"
         res = requests.get(req_url, cookies=self.cookies, headers=self.headers)
         res.raise_for_status()
@@ -423,6 +424,52 @@ class Profile(LinkedIn):
         df = pd.DataFrame(res_json)
         return df.reset_index(drop=True)
 
+    def get_top_card(self, profile_url=None):
+        """
+        Return an dataframe object with 18 columns:
+        - PROFILE_ID
+        - PROFILE_URL
+        - FIRSTNAME
+        - LASTNAME
+        - LASTNAME
+        - OCCUPATION
+        - CONNECTIONS
+        - HASHTAGS
+        - LOCATION
+        - COMPANY_NAME
+        - COMPANY_URL
+        - DATE_START
+        - DATE_END
+        - SCHOOL_NAME
+        - SCHOOL_URL
+        - FOLLOWER_COUNT
+        - DATE_EXTRACT
+
+        Parameters
+        ----------
+        profile_url: str:
+            Profile URL from LinkedIn.
+            Example : "https://www.linkedin.com/in/florent-ravenel/"
+        """
+        res_json = {}
+        if profile_url is None:
+            print("❌ No profile URL. Please enter a profile URL from LinkedIn")
+            return res_json
+        profile_id = LinkedIn.get_profile_id(profile_url)
+        if profile_id is None:
+            return "Please enter a valid profile_url. It must follow this pattern: 'https://*.linkedin.com/in/*' "
+        req_url = f"{LINKEDIN_API}/profile/getTopCard?profile_id={profile_id}"
+        res = requests.post(req_url, json=self.cookies, headers=HEADERS)
+        res.raise_for_status()
+
+        # Manage LinkedIn API errors
+        LinkedIn.manage_api_error(res)
+
+        # Get json result
+        res_json = res.json()
+        df = pd.DataFrame(res_json)
+        return df.reset_index(drop=True)
+
     def get_posts_feed(
         self,
         profile_url,
@@ -921,18 +968,57 @@ class Message(LinkedIn):
         self.cookies = cookies
         self.headers = headers
 
-    def get_conversations(self, limit=-1, count=20):
-        limit_max = 500
-        params = {
-            "limit": limit_max if limit > limit_max or limit == -1 else limit,
-            "count": count,
-        }
-        df_result = None
+    def get_conversations(
+        self,
+        limit=20,
+        sleep=True,
+    ):
+        """
+        Fetches the conversations from LinkedIn API.
+
+        This function sends a POST request to Naas LinkedIn's API endpoint to retrieve conversation data.
+        It retrieves the data in batches (default batch size is 20) and concatenates the results into a pandas DataFrame.
+        The function continues to fetch data until the specified limit is reached, or until there are no more conversations to fetch.
+        An optional sleep parameter can be used to introduce a delay between requests to avoid hitting API rate limits.
+
+        Parameters:
+        limit (int): The maximum number of conversations to fetch. If not specified, defaults to 20. The maximum allowed limit is 600.
+        sleep (bool): Whether to introduce a delay between requests. If not specified, defaults to True.
+
+        Returns:
+        df (pandas.DataFrame): A DataFrame containing the conversation data. The DataFrame consists of the following columns:
+            1. CONVERSATION_ID: The unique identifier for the conversation.
+            2. CONVERSATION_TYPE: The type of conversation (e.g., MEMBER_TO_MEMBER).
+            3. MESSAGE_COUNT: The total number of messages in the conversation.
+            4. UNREAD_MESSAGE_COUNT: The number of unread messages in the conversation.
+            5. FULLNAME: The full name of the other participant in the conversation.
+            6. PROFILE_URL: The LinkedIn profile URL of the other participant.
+            7. PUBLIC_ID: The public identifier of the other participant.
+            8. PROFILE_ID: The profile ID of the other participant.
+            9. FIRSTNAME: The first name of the other participant.
+            10. LASTNAME: The last name of the other participant.
+            11. OCCUPATION: The occupation of the other participant.
+            12. LAST_MESSAGE: The content of the last message in the conversation.
+            13. LAST_MESSAGE_SENT_AT: The timestamp of when the last message was sent.
+            14. LAST_READ_AT: The timestamp of when the last message was read.
+            15. LAST_SENDER_ID: The ID of the last sender.
+            16. LAST_SENDER: The full name of the last sender.
+            17. DATE_EXTRACT: The timestamp of when the conversation data was extracted.
+        """
+
+        # Init
+        df = pd.DataFrame()
+        count = 20
+        limit_max = 600
+
+        # Set count and limit
+        if limit < count:
+            count = limit
+        if limit > limit_max:
+            limit = limit_max
+
+        params = {"count": count}
         while True:
-            if limit != -1:
-                limit -= limit_max
-                if limit < 0:
-                    limit = 0
             req_url = f"{LINKEDIN_API}/message/getConversations?{urllib.parse.urlencode(params, safe='(),')}"
             res = requests.post(req_url, json=self.cookies, headers=HEADERS)
             res.raise_for_status()
@@ -942,42 +1028,74 @@ class Message(LinkedIn):
 
             # Get json result
             res_json = res.json()
-            df = pd.DataFrame(res_json)
-            created_before = (
-                (int)(
-                    datetime.strptime(
-                        df["LAST_ACTIVITY"].iloc[-1], DATETIME_FORMAT
-                    ).timestamp()
-                )
-            ) * 1000
-            params["created_before"] = created_before
-            if df_result is None:
-                df_result = df
-            else:
-                df_result = pd.concat([df_result, df])
-            time.sleep(TIME_SLEEP)
-            if limit == 0 or len(df) < params["limit"]:
+            tmp_df = pd.DataFrame(res_json)
+            df = pd.concat([df, tmp_df])
+
+            # Check if result is not empty else break
+            if len(tmp_df) == 0:
                 break
-        return df_result.reset_index(drop=True)
+            if len(df) >= limit:
+                break
+            # Set created before params
+            last_message_sent_at = tmp_df["LAST_MESSAGE_SENT_AT"].iloc[-1]
+            created_before = int(
+                datetime.strptime(last_message_sent_at, DATETIME_FORMAT).strftime("%s")
+                + "000"
+            )
+            params["created_before"] = created_before
+            if sleep:
+                time.sleep(TIME_SLEEP)
+        return df.reset_index(drop=True)
 
     def get_messages(
-        self, conversation_url=None, conversation_urn=None, start=0, limit=-1, count=20
+        self,
+        conversation_url=None,
+        count=20,
+        limit=20,
+        sleep=False,
     ):
-        req_url = f"{LINKEDIN_API}/message/getMessages?start={start}&limit={limit}&count{count}"
-        if conversation_url:
-            req_url += f"&conversation_url={conversation_url}"
-        if conversation_urn:
-            req_url += f"&conversation_urn={conversation_urn}"
-        res = requests.post(req_url, json=self.cookies, headers=HEADERS)
-        res.raise_for_status()
+        # Init
+        df = pd.DataFrame()
+        start = 0
+        count = 20
+        limit_max = 100
 
-        # Manage LinkedIn API errors
-        LinkedIn.manage_api_error(res)
+        # Get conversation ID
+        conversation_id = conversation_url.split(
+            "https://www.linkedin.com/messaging/thread/"
+        )[-1].split("/")[0]
 
-        # Get json result
-        res_json = res.json()
-        df = pd.DataFrame(res_json)
-        time.sleep(TIME_SLEEP)
+        # Set count and limit
+        if limit < count:
+            count = limit
+        if limit > limit_max:
+            limit = limit_max
+        while True:
+            params = {
+                "conversation_id": conversation_id,
+                "start": start,
+                "count": count,
+            }
+            req_url = f"{LINKEDIN_API}/message/getMessages?{urllib.parse.urlencode(params, safe='(),')}"
+            res = requests.post(req_url, json=self.cookies, headers=HEADERS)
+            res.raise_for_status()
+
+            # Manage LinkedIn API errors
+            LinkedIn.manage_api_error(res)
+
+            # Get json result
+            res_json = res.json()
+            if len(res_json) > 0:
+                tmp_df = pd.DataFrame(res_json)
+                df = pd.concat([df, tmp_df])
+            # Check if result is not empty else break
+            if len(res_json) == 0 or len(res_json) < count:
+                break
+            if len(df) >= limit:
+                break
+            start += count
+            if sleep:
+                time.sleep(TIME_SLEEP)
         return df.reset_index(drop=True)
 
     def send(self, content, recipients_url=None, recipients_urn=None):
